@@ -2,5 +2,5 @@ document.querySelectorAll('code[class^="language-"]').forEach(function(element)
     var c = element.getAttribute('class');
     element.setAttribute('class', c.replace(/language-/g, ''));
 
-    hljs.highlightBlock(element);
+    hljs.highlightElement(element);
 });
\ No newline at end of file
